import { getKycs } from "@/app/lib/kyc/action";
import { Box } from "@chakra-ui/react";
import KYCTable from "./components/table";
import { usersRequestList } from "@/app/lib/users/action";
import { getIbcRequestList } from "@/app/lib/ibc/action";
import { prepareUsersDropdown } from "@/utils/common";
import { IbcInterface } from "@/types/settings/ibc/ibc";

const List = async ({
  searchParams,
}: {
  searchParams?: { [key: string]: string | number };
}) => {
  const [kycs, users, ibcs] = await Promise.all([
    getKycs({ ...searchParams }),
    usersRequestList({ pagination: 'false' }),
    getIbcRequestList({ pagination: 'false' }),
  ]);

  // Prepare data for users dropdown
  const usersDropdown = prepareUsersDropdown(users);

  // Prepare data for users dropdown
  const ibcsDropdown = ibcs.data && ibcs.data.length > 0
    ? ibcs.data.map((ibc: IbcInterface) => ({
      label: `${ibc.area_name}`,
      value: ibc.id,
    }))
    : [];

  return (
    <Box pt={{ base: "130px", md: "80px", xl: "80px" }} mb="20px">
      {kycs && kycs.data ? <KYCTable data={kycs} users={usersDropdown} ibcs={ibcsDropdown} /> : null}
    </Box>
  );
};

export default List;
